==> RSCABS_0.9.2.tar.gz: RSCABS/R/RSCABS-internal.R <==

.Random.seed <-
c(403L, 10L, -1187574461L, -1255253934L, -1577882908L, 776219943L, 
-1789561475L, -1549345676L, 546391642L, -1638497627L, 792053951L, 
26540870L, -1735734832L, 1622465523L, -568622319L, 2117079872L, 
1632156446L, 1349649385L, -1012889317L, 111158058L, -1249876916L, 
1478716431L, -11122875L, 1950839036L, 291716946L, 855421133L, 
660455559L, -956816530L, 995874120L, -163684021L, 1348687017L, 
1306928632L, 1258360102L, 684977729L, 163768275L, 208780674L, 
822399412L, 130710839L, 1105868845L, 1703290180L, 452862570L, 
907234517L, 1558973039L, -1420804234L, -442990432L, 799807843L, 
545577473L, 1152928112L, 878115086L, -590328967L, 292340491L, 
1320799290L, 2112744252L, -718815105L, -155032619L, -1698853396L, 
1020272450L, 438378653L, -1585145577L, 473034878L, 1070942264L, 
-1995612389L, 2041359481L, -727993144L, 124507382L, -2001484495L, 
-1548061341L, -613050574L, -759775100L, -219112249L, -1817047139L, 
-1551746284L, -1357624902L, 1057775621L, -773417505L, -759863194L, 
-1750935568L, -330227437L, 1432518321L, 1701362016L, 1027346174L, 
-332633463L, -77658693L, -860029046L, 1656579692L, 588273647L, 
-939921371L, 108888284L, -774445390L, -1795749459L, -681968281L, 
598190734L, -761547928L, 1441753963L, 90002697L, -553178216L, 
-1366316346L, 1264095265L, 1130058931L, -563001822L, -453937132L, 
2109078679L, 629823117L, -1479198812L, 1329408394L, 616928757L, 
1436321871L, -1412948138L, 1539700224L, -747485373L, 924065505L, 
1250196560L, 1254245550L, 1945100377L, 431259755L, -678578726L, 
-1834475876L, -1800327009L, 1398459125L, -14100596L, -136907166L, 
425740861L, 1783362743L, 2094607198L, -240644456L, 112258555L, 
-1178685543L, 299337768L, -1279430442L, -588958383L, 1599628291L, 
670075794L, 623372580L, -864964633L, -850217923L, 357270196L, 
1787498778L, 1060135525L, -857815297L, -789726330L, -1585177328L, 
-1449683533L, 1325549137L, 1139811840L, -2115607842L, -491294423L, 
-957850405L, -253793302L, -1141752948L, 299302095L, -201087867L, 
2029612860L, -773820910L, 160361741L, -211601849L, -13243346L, 
-1600622200L, 1847437451L, -420101527L, -1761100232L, 1126422246L, 
-130125183L, -205062637L, 1245743554L, 1485644404L, -759413641L, 
166923629L, 476656132L, 50401578L, 749749909L, 2029464879L, -1446438858L, 
-1738265504L, 869909155L, 1974597057L, 1833976240L, 418390222L, 
1384234553L, -1454440373L, -336940550L, -1862996740L, 1218085183L, 
-714441195L, 1210170668L, -2012672510L, -789375779L, 1238241239L, 
-1331795266L, -303469320L, 620417755L, -382236359L, 879938696L, 
-1057473482L, 858490993L, -2045953373L, 1182408690L, -1985105084L, 
-1371988985L, -2109523491L, -1468823852L, -2082657798L, 1940981061L, 
1639698847L, 1668674342L, -1014379600L, -1123665837L, 7025521L, 
1193853600L, 1449571902L, -1647002295L, -1192393733L, -152574006L, 
1744853292L, 1826583855L, -2056160283L, -1102364004L, -1465645326L, 
452302701L, 2113757351L, -821042482L, -9433048L, 263334955L, 
-29024695L, 343037784L, 1459667462L, 1942711265L, 545556851L, 
1560586722L, 89443668L, -794785294L, 1759893040L, -659212380L, 
-1172803144L, -65698982L, 822244496L, 1322560380L, 1332864788L, 
2124860738L, -2003112192L, -1999776836L, -2045784240L, -1733687006L, 
-849616312L, 484675596L, -1221995428L, -1881919022L, -1072972288L, 
-109665964L, -274870040L, -842440454L, -344373552L, 1410650412L, 
-1924112140L, 1278086546L, 634050912L, 437770252L, 1021428448L, 
852011618L, -359087448L, 365226572L, -1451233412L, 51352882L, 
-582850960L, 1983345476L, -666015784L, 923404154L, -1464879568L, 
1811605436L, -1414547884L, 711512130L, 1945858208L, -959924548L, 
-1498256944L, 720290658L, -1911315736L, 351060172L, 638181884L, 
911208946L, -2079454592L, 1113038324L, 990787208L, -358621382L, 
891442000L, 714206316L, -595689068L, -135056302L, -69336608L, 
1628724428L, 329761952L, 1775891842L, 806799592L, 468088556L, 
1635472700L, -806548366L, 1849682032L, -1222770652L, 292703288L, 
-1805439206L, 2066640080L, -118440132L, -547297388L, -1833217150L, 
1882868160L, -1999700420L, 1691436432L, 81083938L, -1023859448L, 
697937548L, 1729994524L, -17514350L, 487373184L, 901867028L, 
-1596809432L, -206955974L, -1958724144L, -2774676L, 1584169908L, 
-151955438L, -750291488L, -1629141044L, -463609632L, 1210325026L, 
1178034472L, -498590196L, -2035013828L, 362464242L, 1670159088L, 
-538915260L, -1921236392L, 785764154L, 1859053040L, 825185980L, 
-642336492L, 263537346L, 1871574112L, 1531118460L, 914298832L, 
1248911650L, -1725138264L, 1759189900L, -1650411332L, 170848050L, 
925805120L, -2029028172L, 882123336L, 1872192954L, 2009793040L, 
-2059472148L, -788782764L, 408502546L, -1542959712L, -791043380L, 
-442294688L, -734169150L, -197859544L, -1868730452L, 1679942460L, 
131049842L, -1969784016L, 117271844L, 131509048L, -612032806L, 
-1525962864L, 1043484412L, -2079413356L, -1372970942L, 494163200L, 
-1727495108L, 890683728L, 1530728610L, -1611833016L, -1507387636L, 
1694941916L, -996971182L, 1180976256L, -900030380L, -1491562520L, 
-1441486598L, -1318606000L, -251887828L, -787371660L, -2120029294L, 
2104109152L, -367178356L, -606839968L, -1936377374L, 435516328L, 
711013580L, 1929641980L, -1247746638L, -1182501392L, 1793199044L, 
979805528L, 1819695482L, -1606351952L, 537168316L, -647481260L, 
1933326274L, 1814966304L, -1223870276L, -926838192L, 1990439906L, 
-586416024L, 45728844L, -1178494724L, -527102990L, 856606976L, 
-937475724L, -880546808L, -216629318L, -834981424L, -2101183508L, 
1713578388L, 487330258L, 829133152L, -951267508L, -1906681568L, 
-890552446L, -1900368152L, -31211284L, -1795574724L, -55198862L, 
-111526288L, -426372060L, 1989495608L, -621302630L, 2014057168L, 
-973209412L, -163631468L, 688109186L, -92714816L, -2138987716L, 
664296592L, 1556282914L, -23474168L, 305667340L, 1030663324L, 
-542147054L, 2057076608L, 115133972L, -1537398232L, -1892027078L, 
494488016L, -259640212L, -2123388620L, 853677714L, 1029704544L, 
-1513163956L, -1451837472L, -1585047646L, -304085080L, 1318563212L, 
-1262778180L, 1990166898L, -693365520L, 503263300L, 1930120445L, 
525645895L, 194316080L, -886677426L, 42921083L, 1657454557L, 
-2101957110L, 1210544936L, -1111900783L, -1857354877L, 1399154820L, 
-2136734030L, 1527880199L, -753276335L, -1735794218L, -1144091468L, 
2071034053L, -473757169L, 748020360L, -1462659162L, 1807998803L, 
-1248026443L, -1674707438L, -1527997472L, -1794134455L, 1813326971L, 
-1074016948L, 968947930L, -1375041329L, -712944487L, -427648850L, 
-1974221380L, -1991320019L, -226117161L, -433106912L, -1244711554L, 
-868865205L, -2052591283L, -263336070L, -309321288L, -521157791L, 
1789776659L, 1269050164L, -244373182L, -354390697L, -160397151L, 
-1758207642L, 1685984100L, -323896683L, -146375745L, -1419849896L, 
1467712886L, 2079614851L, 1912815045L, -1520352542L, -2131399856L, 
255948409L, -937330261L, -1394159844L, 1887606858L, -1755575233L, 
307661961L, -1212258146L, 408118604L, 1458685213L, 2054946983L, 
941486032L, 191473518L, 869223963L, 1638709117L, 442940778L, 
-1597008888L, 273259697L, 272218915L, 1487161380L, 1615743698L, 
-1950736601L, -2016722575L, -1401124938L, 1944582996L, 1934821L, 
35618799L, -963551448L, -786897018L, 1968427955L, -1684131051L, 
831245682L, 1887121856L, 545530409L, -961878373L, 886746988L, 
-820889734L, -984559441L, 1949068217L, 1921088974L, -1112004324L, 
-1270643L, 2113736951L, 1746705408L, -1588945314L, -84082389L, 
109732397L, -377232742L, -266035624L, -1947622975L, 925380211L, 
-2135020652L, 1507992098L, -1041552073L, -1021850623L, -250384122L, 
-495315644L, -104023947L, 72882655L, 785130808L, 1675802390L, 
-763971805L, 1022149861L, 652181762L, -542084240L, -214144231L, 
-1451357429L, 1177114620L, -823151574L, 1986123871L, -754905111L, 
1110175998L, 459415788L, -1061010371L, -1492404217L, -1604533264L, 
690589582L, 2037255611L, -1923945571L, -2091814582L, -1411573400L, 
146509649L, 159124547L, 1350227268L, 613774834L, -1452245049L, 
-1931066991L, 239269142L, 293735796L, 1091963909L, 1691974735L, 
896143432L, -725711386L, 664460051L, -93504395L, 297281106L, 
-167485280L, 1764505993L, 588233147L, 1653413388L, -585920614L, 
2102245135L, 434744665L, -1643624466L, 557362812L, 1116444397L, 
-1097473641L, -772887968L, 969302078L, -497768181L, -762565747L, 
-1197643590L, -1391972616L, -1024432991L, -1447229858L)

==> RSCABS_0.9.3.tar.gz: RSCABS/R/RSCABS-internal.R <==

.Random.seed <-
c(403L, 10L, -1187574461L, -1255253934L, -1577882908L, 776219943L, 
-1789561475L, -1549345676L, 546391642L, -1638497627L, 792053951L, 
26540870L, -1735734832L, 1622465523L, -568622319L, 2117079872L, 
1632156446L, 1349649385L, -1012889317L, 111158058L, -1249876916L, 
1478716431L, -11122875L, 1950839036L, 291716946L, 855421133L, 
660455559L, -956816530L, 995874120L, -163684021L, 1348687017L, 
1306928632L, 1258360102L, 684977729L, 163768275L, 208780674L, 
822399412L, 130710839L, 1105868845L, 1703290180L, 452862570L, 
907234517L, 1558973039L, -1420804234L, -442990432L, 799807843L, 
545577473L, 1152928112L, 878115086L, -590328967L, 292340491L, 
1320799290L, 2112744252L, -718815105L, -155032619L, -1698853396L, 
1020272450L, 438378653L, -1585145577L, 473034878L, 1070942264L, 
-1995612389L, 2041359481L, -727993144L, 124507382L, -2001484495L, 
-1548061341L, -613050574L, -759775100L, -219112249L, -1817047139L, 
-1551746284L, -1357624902L, 1057775621L, -773417505L, -759863194L, 
-1750935568L, -330227437L, 1432518321L, 1701362016L, 1027346174L, 
-332633463L, -77658693L, -860029046L, 1656579692L, 588273647L, 
-939921371L, 108888284L, -774445390L, -1795749459L, -681968281L, 
598190734L, -761547928L, 1441753963L, 90002697L, -553178216L, 
-1366316346L, 1264095265L, 1130058931L, -563001822L, -453937132L, 
2109078679L, 629823117L, -1479198812L, 1329408394L, 616928757L, 
1436321871L, -1412948138L, 1539700224L, -747485373L, 924065505L, 
1250196560L, 1254245550L, 1945100377L, 431259755L, -678578726L, 
-1834475876L, -1800327009L, 1398459125L, -14100596L, -136907166L, 
425740861L, 1783362743L, 2094607198L, -240644456L, 112258555L, 
-1178685543L, 299337768L, -1279430442L, -588958383L, 1599628291L, 
670075794L, 623372580L, -864964633L, -850217923L, 357270196L, 
1787498778L, 1060135525L, -857815297L, -789726330L, -1585177328L, 
-1449683533L, 1325549137L, 1139811840L, -2115607842L, -491294423L, 
-957850405L, -253793302L, -1141752948L, 299302095L, -201087867L, 
2029612860L, -773820910L, 160361741L, -211601849L, -13243346L, 
-1600622200L, 1847437451L, -420101527L, -1761100232L, 1126422246L, 
-130125183L, -205062637L, 1245743554L, 1485644404L, -759413641L, 
166923629L, 476656132L, 50401578L, 749749909L, 2029464879L, -1446438858L, 
-1738265504L, 869909155L, 1974597057L, 1833976240L, 418390222L, 
1384234553L, -1454440373L, -336940550L, -1862996740L, 1218085183L, 
-714441195L, 1210170668L, -2012672510L, -789375779L, 1238241239L, 
-1331795266L, -303469320L, 620417755L, -382236359L, 879938696L, 
-1057473482L, 858490993L, -2045953373L, 1182408690L, -1985105084L, 
-1371988985L, -2109523491L, -1468823852L, -2082657798L, 1940981061L, 
1639698847L, 1668674342L, -1014379600L, -1123665837L, 7025521L, 
1193853600L, 1449571902L, -1647002295L, -1192393733L, -152574006L, 
1744853292L, 1826583855L, -2056160283L, -1102364004L, -1465645326L, 
452302701L, 2113757351L, -821042482L, -9433048L, 263334955L, 
-29024695L, 343037784L, 1459667462L, 1942711265L, 545556851L, 
1560586722L, 89443668L, -794785294L, 1759893040L, -659212380L, 
-1172803144L, -65698982L, 822244496L, 1322560380L, 1332864788L, 
2124860738L, -2003112192L, -1999776836L, -2045784240L, -1733687006L, 
-849616312L, 484675596L, -1221995428L, -1881919022L, -1072972288L, 
-109665964L, -274870040L, -842440454L, -344373552L, 1410650412L, 
-1924112140L, 1278086546L, 634050912L, 437770252L, 1021428448L, 
852011618L, -359087448L, 365226572L, -1451233412L, 51352882L, 
-582850960L, 1983345476L, -666015784L, 923404154L, -1464879568L, 
1811605436L, -1414547884L, 711512130L, 1945858208L, -959924548L, 
-1498256944L, 720290658L, -1911315736L, 351060172L, 638181884L, 
911208946L, -2079454592L, 1113038324L, 990787208L, -358621382L, 
891442000L, 714206316L, -595689068L, -135056302L, -69336608L, 
1628724428L, 329761952L, 1775891842L, 806799592L, 468088556L, 
1635472700L, -806548366L, 1849682032L, -1222770652L, 292703288L, 
-1805439206L, 2066640080L, -118440132L, -547297388L, -1833217150L, 
1882868160L, -1999700420L, 1691436432L, 81083938L, -1023859448L, 
697937548L, 1729994524L, -17514350L, 487373184L, 901867028L, 
-1596809432L, -206955974L, -1958724144L, -2774676L, 1584169908L, 
-151955438L, -750291488L, -1629141044L, -463609632L, 1210325026L, 
1178034472L, -498590196L, -2035013828L, 362464242L, 1670159088L, 
-538915260L, -1921236392L, 785764154L, 1859053040L, 825185980L, 
-642336492L, 263537346L, 1871574112L, 1531118460L, 914298832L, 
1248911650L, -1725138264L, 1759189900L, -1650411332L, 170848050L, 
925805120L, -2029028172L, 882123336L, 1872192954L, 2009793040L, 
-2059472148L, -788782764L, 408502546L, -1542959712L, -791043380L, 
-442294688L, -734169150L, -197859544L, -1868730452L, 1679942460L, 
131049842L, -1969784016L, 117271844L, 131509048L, -612032806L, 
-1525962864L, 1043484412L, -2079413356L, -1372970942L, 494163200L, 
-1727495108L, 890683728L, 1530728610L, -1611833016L, -1507387636L, 
1694941916L, -996971182L, 1180976256L, -900030380L, -1491562520L, 
-1441486598L, -1318606000L, -251887828L, -787371660L, -2120029294L, 
2104109152L, -367178356L, -606839968L, -1936377374L, 435516328L, 
711013580L, 1929641980L, -1247746638L, -1182501392L, 1793199044L, 
979805528L, 1819695482L, -1606351952L, 537168316L, -647481260L, 
1933326274L, 1814966304L, -1223870276L, -926838192L, 1990439906L, 
-586416024L, 45728844L, -1178494724L, -527102990L, 856606976L, 
-937475724L, -880546808L, -216629318L, -834981424L, -2101183508L, 
1713578388L, 487330258L, 829133152L, -951267508L, -1906681568L, 
-890552446L, -1900368152L, -31211284L, -1795574724L, -55198862L, 
-111526288L, -426372060L, 1989495608L, -621302630L, 2014057168L, 
-973209412L, -163631468L, 688109186L, -92714816L, -2138987716L, 
664296592L, 1556282914L, -23474168L, 305667340L, 1030663324L, 
-542147054L, 2057076608L, 115133972L, -1537398232L, -1892027078L, 
494488016L, -259640212L, -2123388620L, 853677714L, 1029704544L, 
-1513163956L, -1451837472L, -1585047646L, -304085080L, 1318563212L, 
-1262778180L, 1990166898L, -693365520L, 503263300L, 1930120445L, 
525645895L, 194316080L, -886677426L, 42921083L, 1657454557L, 
-2101957110L, 1210544936L, -1111900783L, -1857354877L, 1399154820L, 
-2136734030L, 1527880199L, -753276335L, -1735794218L, -1144091468L, 
2071034053L, -473757169L, 748020360L, -1462659162L, 1807998803L, 
-1248026443L, -1674707438L, -1527997472L, -1794134455L, 1813326971L, 
-1074016948L, 968947930L, -1375041329L, -712944487L, -427648850L, 
-1974221380L, -1991320019L, -226117161L, -433106912L, -1244711554L, 
-868865205L, -2052591283L, -263336070L, -309321288L, -521157791L, 
1789776659L, 1269050164L, -244373182L, -354390697L, -160397151L, 
-1758207642L, 1685984100L, -323896683L, -146375745L, -1419849896L, 
1467712886L, 2079614851L, 1912815045L, -1520352542L, -2131399856L, 
255948409L, -937330261L, -1394159844L, 1887606858L, -1755575233L, 
307661961L, -1212258146L, 408118604L, 1458685213L, 2054946983L, 
941486032L, 191473518L, 869223963L, 1638709117L, 442940778L, 
-1597008888L, 273259697L, 272218915L, 1487161380L, 1615743698L, 
-1950736601L, -2016722575L, -1401124938L, 1944582996L, 1934821L, 
35618799L, -963551448L, -786897018L, 1968427955L, -1684131051L, 
831245682L, 1887121856L, 545530409L, -961878373L, 886746988L, 
-820889734L, -984559441L, 1949068217L, 1921088974L, -1112004324L, 
-1270643L, 2113736951L, 1746705408L, -1588945314L, -84082389L, 
109732397L, -377232742L, -266035624L, -1947622975L, 925380211L, 
-2135020652L, 1507992098L, -1041552073L, -1021850623L, -250384122L, 
-495315644L, -104023947L, 72882655L, 785130808L, 1675802390L, 
-763971805L, 1022149861L, 652181762L, -542084240L, -214144231L, 
-1451357429L, 1177114620L, -823151574L, 1986123871L, -754905111L, 
1110175998L, 459415788L, -1061010371L, -1492404217L, -1604533264L, 
690589582L, 2037255611L, -1923945571L, -2091814582L, -1411573400L, 
146509649L, 159124547L, 1350227268L, 613774834L, -1452245049L, 
-1931066991L, 239269142L, 293735796L, 1091963909L, 1691974735L, 
896143432L, -725711386L, 664460051L, -93504395L, 297281106L, 
-167485280L, 1764505993L, 588233147L, 1653413388L, -585920614L, 
2102245135L, 434744665L, -1643624466L, 557362812L, 1116444397L, 
-1097473641L, -772887968L, 969302078L, -497768181L, -762565747L, 
-1197643590L, -1391972616L, -1024432991L, -1447229858L)


.invertOrder<-function(Data,ColNames){
#' @export
#For each listed vector of data, finds the an inverts the range of numbers 
#Will 


R<-Data[ ,ColNames]
R<-cbind(R) #ensures X has at least 1 column vector

#This inverts the rank of the number while preserving the differences between the numbers
	R1<-apply(R,2,function(X){
		X<-convert2Score(X)
		if (sum(is.na(X))==length(X)){
			return(X)
		}
		return(-X+max(X,na.rm=TRUE)+min(X,na.rm=TRUE))
	})

	
Data[ ,ColNames]<-R1
return(Data)	
}



.orderOutput<-function(Results){
	#' @export	
	#This function take the Results from RSCABSMain and reorders them to be easer to read 


	Response<-strsplit(as.character(Results$Response),'')
	#Remove the last character
	Response<-lapply(Response,function(x){
		return(paste0(x[-length(x)],collapse=''))
		})
	Response<-unlist(Response)

	Results$Response<-Response

	#Order based on R-Score
	Results<-Results[order(Results$Response,Results[ ,'R-Score'],decreasing = TRUE), ]

	#swap R-Score and Treatment
	Results[ ,c(2,3)] <-Results[ ,c(3,2)] 
	colnames(Results)[c(2,3)]<-colnames(Results)[c(3,2)]

	#Re-paste the responses together
	Results$Response<-paste0(Results$Response,Results[ ,'R-Score'])

	return(Results)
}



.tagInvert<-function(Results,Data,ColNames){
#' @export
#This function inverts the the R-Score listed for results

	
	Response<-strsplit(as.character(Results$Response),'')
	#Remove the last character
	Response<-lapply(Response,function(x){
		return(paste0(x[-length(x)],collapse=''))
		})
	Response<-unlist(Response)

	#Apply use tested endpoints
	ColNamesResponse<-ColNames[which(is.element(ColNames,Response)==TRUE)]
	
	#Add IsInverted tag
	Inverted<-rep('',length(Response))
	
	#Apply the inversion algorithm to the R-Score of every inverted Endpoint
	for (e in ColNamesResponse){
		R<-Data[ ,e]
		R<-convert2Score(R)
		iIndex<-which(Response==e)
		RScores<-Results[iIndex,'R-Score']
		Results[iIndex,'R-Score']<- {-RScores+max(R,na.rm=TRUE)+min(R,na.rm=TRUE)}
		Inverted[iIndex]<-'Yes'
	}
	
	#Add the last character back in
	Results$Response<-paste0(Response,Results[ ,'R-Score'])
	Results<-cbind(Results,Inverted)
	
	
return(Results)	
}
